==> ecompus-cas-1.0.1-sources.jar: edu/ecompus/cas/dao/impl/CompanyRegDaoImpl.java <==
package edu.ecompus.cas.dao.impl;

import java.util.List;


import org.springframework.stereotype.Repository;

import edu.ecompus.cas.dao.CompanyRegDAO;
import edu.ecompus.cas.entity.CompanyReg;
import edu.ecompus.core.dao.impl.ML2TemplateGenericDao;
import edu.ecompus.core.entity.Page;
/**
 * <b>机构注册申请表</b> 数据持久类 操作接口实现类
 * 
 * 
 * @CopyRight CopyRright (c) 2013:   <紫悦新橙>
 * Project:               <数字化校园 >
 * Module ID:   <(模块)类编号，可以引用系统设计中的类编号>
 * Comments:  <对此类的描述，可以引用系统设计中的描述>
 * JDK version used:      <JDK1.6> 
 * @author JannyShao(邵建义) [ksgameboy@qq.com]
 * @since Date： 2014-7-28 上午9:31:37
 */
@Repository
public class CompanyRegDaoImpl extends ML2TemplateGenericDao<CompanyReg> implements
		CompanyRegDAO {

	public CompanyRegDaoImpl() {
		super(CompanyReg.class);
	}


	@SuppressWarnings("unchecked")
	@Override
	public List<CompanyReg> queryCompanyRegListByCompanyId(Long companyId) {
		StringBuffer sql = new StringBuffer("from CompanyReg where schoolId = ").append(companyId);
		return this.hibernateTemplate.find(sql.toString());
	}

	@SuppressWarnings("unchecked")
	@Override
	public List<CompanyReg> queryCompanyRegList(String keyword, int type,
			String province, String city, Page page) {
		StringBuffer sql = new StringBuffer("from CompanyReg where id>0 ");
		
		if(keyword!=null && !"".equals(keyword)){
			sql.append(" and ( name like '%").append(keyword).append("%'");
			sql.append(" or contact like '%").append(keyword).append("%')");
		}
		
		if(type!=-1){
			sql.append(" and type=").append(type);
		}
		
		if(province!=null && !"".equals(province)){
			sql.append(" and province like '%").append(province).append("%'");
		}
		
		if(city!=null && !"".equals(city)){
			sql.append(" and city like '%").append(city).append("%'");
		}
		
		sql.append(" order by createDate desc ");
		
		logger.info(sql.toString());
		if(page==null){
			return this.hibernateTemplate.find(sql.toString());
		}
		
		return this.queryForList("select count(*) " + sql.toString(),
				sql.toString(), new Object[] {  }, page);
	}

}

==> ecompus-cas-1.0.2-sources.jar: edu/ecompus/cas/dao/impl/CompanyRegDaoImpl.java <==
package edu.ecompus.cas.dao.impl;

import java.util.List;


import org.springframework.stereotype.Repository;

import edu.ecompus.cas.dao.CompanyRegDAO;
import edu.ecompus.cas.entity.CompanyReg;
import edu.ecompus.core.dao.impl.ML2TemplateGenericDao;
import edu.ecompus.core.entity.Page;
/**
 * <b>机构注册申请表</b> 数据持久类 操作接口实现类
 * 
 * 
 * @CopyRight CopyRright (c) 2013:   <紫悦新橙>
 * Project:               <数字化校园 >
 * Module ID:   <(模块)类编号，可以引用系统设计中的类编号>
 * Comments:  <对此类的描述，可以引用系统设计中的描述>
 * JDK version used:      <JDK1.6> 
 * @author JannyShao(邵建义) [ksgameboy@qq.com]
 * @since Date： 2014-7-28 上午9:31:37
 */
@Repository
public class CompanyRegDaoImpl extends ML2TemplateGenericDao<CompanyReg> implements
		CompanyRegDAO {

	public CompanyRegDaoImpl() {
		super(CompanyReg.class);
	}


	@SuppressWarnings("unchecked")
	@Override
	public List<CompanyReg> queryCompanyRegListByCompanyId(Long companyId) {
		StringBuffer sql = new StringBuffer("from CompanyReg where schoolId = ").append(companyId);
		return this.hibernateTemplate.find(sql.toString());
	}

	@SuppressWarnings("unchecked")
	@Override
	public List<CompanyReg> queryCompanyRegList(String keyword, int type,
			String province, String city, Page page) {
		StringBuffer sql = new StringBuffer("from CompanyReg where id>0 ");
		
		if(keyword!=null && !"".equals(keyword)){
			sql.append(" and ( name like '%").append(keyword).append("%'");
			sql.append(" or contact like '%").append(keyword).append("%')");
		}
		
		if(type!=-1){
			sql.append(" and type=").append(type);
		}
		
		if(province!=null && !"".equals(province)){
			sql.append(" and province like '%").append(province).append("%'");
		}
		
		if(city!=null && !"".equals(city)){
			sql.append(" and city like '%").append(city).append("%'");
		}
		
		sql.append(" order by createDate desc ");
		
		logger.info(sql.toString());
		if(page==null){
			return this.hibernateTemplate.find(sql.toString());
		}
		
		return this.queryForList("select count(id) " + sql.toString(),
				sql.toString(), new Object[] {  }, page);
	}

}
